Method: Pod::Installer::InstallationOptions#incremental_installation

Defined in:
lib/cocoapods/installer/installation_options.rb

#incremental_installationBoolean

Note:

this option defaults to false.

Whether to enable only regenerating targets and their associate projects that have changed since the previous installation.

Returns:

  • (Boolean)

    the incremental_installation option for installation.



188
# File 'lib/cocoapods/installer/installation_options.rb', line 188

option :incremental_installation, false