Method: Pod::AggregateTarget#framework_paths_by_config

Defined in:
lib/cocoapods/target/aggregate_target.rb

#framework_paths_by_configHash{String => Array<FrameworkPaths>}

Returns The vendored dynamic artifacts and framework target input and output paths grouped by config.

Returns:

  • (Hash{String => Array<FrameworkPaths>})

    The vendored dynamic artifacts and framework target input and output paths grouped by config



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/cocoapods/target/aggregate_target.rb', line 251

def framework_paths_by_config
  @framework_paths_by_config ||= begin
    framework_paths_by_config = {}
    user_build_configurations.each_key do |config|
      relevant_pod_targets = pod_targets_for_build_configuration(config)
      framework_paths_by_config[config] = relevant_pod_targets.flat_map do |pod_target|
        library_specs = pod_target.library_specs.map(&:name)
        pod_target.framework_paths.values_at(*library_specs).flatten.compact.uniq
      end
    end
    framework_paths_by_config
  end
end