Method: Pod::AggregateTarget#relative_pods_root

Defined in:
lib/cocoapods/target/aggregate_target.rb

#relative_pods_rootString

Returns The xcconfig path of the root from the ‘$(SRCROOT)` variable of the user’s project.

Returns:

  • (String)

    The xcconfig path of the root from the ‘$(SRCROOT)` variable of the user’s project.



434
435
436
# File 'lib/cocoapods/target/aggregate_target.rb', line 434

def relative_pods_root
  "${SRCROOT}/#{relative_pods_root_path}"
end