Class: Pod::Downloader::Response

Inherits:
Struct
  • Object
show all
Defined in:
lib/cocoapods/downloader/response.rb

Overview

A response to a download request.

Instance Attribute Summary collapse

Instance Attribute Details

#checkout_options ⇒ Hash<Symbol, String>

the downloader parameters necessary to recreate this exact download.

Returns:

  • (Hash<Symbol, String>) —

    the current value of checkout_options



14
15
16
# File 'lib/cocoapods/downloader/response.rb', line 14

def checkout_options
  @checkout_options
end

#location ⇒ Pathname

the location where this downloaded pod is stored on disk.

Returns:

  • (Pathname) —

    the current value of location



14
15
16
# File 'lib/cocoapods/downloader/response.rb', line 14

def location
  @location
end

#spec ⇒ Specification

the specification that describes this downloaded pod.

Returns:



14
15
16
# File 'lib/cocoapods/downloader/response.rb', line 14

def spec
  @spec
end