Method: Pod::Installer::PodSourceDownloader#specs_by_platform

Defined in:
lib/cocoapods/installer/pod_source_downloader.rb

#specs_by_platformHash{Symbol=>Array} (readonly)

Returns The specifications that need to be installed grouped by platform.

Returns:

  • (Hash{Symbol=>Array})

    The specifications that need to be installed grouped by platform.



24
25
26
# File 'lib/cocoapods/installer/pod_source_downloader.rb', line 24

def specs_by_platform
  @specs_by_platform
end