Class: Pod::Installer::UserProjectIntegrator
- Inherits:
-
Object
- Object
- Pod::Installer::UserProjectIntegrator
- Defined in:
- lib/cocoapods/installer/user_project_integrator.rb,
lib/cocoapods/installer/user_project_integrator/target_integrator.rb,
lib/cocoapods/installer/user_project_integrator/target_integrator/xcconfig_integrator.rb
Overview
The UserProjectIntegrator integrates the libraries generated by TargetDefinitions of the Podfile with their correspondent user projects.
Defined Under Namespace
Classes: TargetIntegrator
Instance Attribute Summary collapse
-
#installation_root ⇒ Pathname
readonly
The path of the installation.
-
#podfile ⇒ Podfile
readonly
The podfile that should be integrated with the user projects.
-
#sandbox ⇒ Project
readonly
attr_reader :pods_project.
-
#targets ⇒ Array<AggregateTarget>
readonly
The targets represented in the Podfile.
Instance Method Summary collapse
-
#initialize(podfile, sandbox, installation_root, targets) ⇒ UserProjectIntegrator
constructor
Init a new UserProjectIntegrator.
-
#integrate! ⇒ void
Integrates the user projects associated with the TargetDefinitions with the Pods project and its products.
Constructor Details
#initialize(podfile, sandbox, installation_root, targets) ⇒ UserProjectIntegrator
TODO:
Too many initialization arguments
Init a new UserProjectIntegrator
49 50 51 52 53 54 |
# File 'lib/cocoapods/installer/user_project_integrator.rb', line 49 def initialize(podfile, sandbox, installation_root, targets) @podfile = podfile @sandbox = sandbox @installation_root = installation_root @targets = targets end |
Instance Attribute Details
#installation_root ⇒ Pathname (readonly)
34 35 36 |
# File 'lib/cocoapods/installer/user_project_integrator.rb', line 34 def installation_root @installation_root end |
#podfile ⇒ Podfile (readonly)
19 20 21 |
# File 'lib/cocoapods/installer/user_project_integrator.rb', line 19 def podfile @podfile end |
#sandbox ⇒ Project (readonly)
attr_reader :pods_project
26 27 28 |
# File 'lib/cocoapods/installer/user_project_integrator.rb', line 26 def sandbox @sandbox end |
#targets ⇒ Array<AggregateTarget> (readonly)
38 39 40 |
# File 'lib/cocoapods/installer/user_project_integrator.rb', line 38 def targets @targets end |
Instance Method Details
#integrate! ⇒ void
This method returns an undefined value.
Integrates the user projects associated with the TargetDefinitions with the Pods project and its products.
61 62 63 64 65 66 |
# File 'lib/cocoapods/installer/user_project_integrator.rb', line 61 def integrate! create_workspace integrate_user_targets warn_about_empty_podfile warn_about_xcconfig_overrides end |