Method: Pod::Sandbox::FileAccessor#vendored_dynamic_frameworks

Defined in:
lib/cocoapods/sandbox/file_accessor.rb

#vendored_dynamic_frameworksArray<Pathname>

Returns The paths of the dynamic framework bundles that come shipped with the Pod.

Returns:

  • (Array<Pathname>)

    The paths of the dynamic framework bundles that come shipped with the Pod.



176
177
178
179
180
# File 'lib/cocoapods/sandbox/file_accessor.rb', line 176

def vendored_dynamic_frameworks
  (vendored_frameworks - vendored_xcframeworks).select do |framework|
    Xcode::LinkageAnalyzer.dynamic_binary?(framework + framework.basename('.*'))
  end
end