Method: Pod::Sandbox::HeadersStore#initialize

Defined in:
lib/cocoapods/sandbox/headers_store.rb

#initialize(sandbox, relative_path, visibility_scope) ⇒ HeadersStore

Returns a new instance of HeadersStore.

Parameters:

  • @see (Sandbox)

    #sandbox

  • relative_path (String)

    the relative path to the sandbox root and hence to the Pods project.

  • visibility_scope (Symbol)

    the header visibility scope to use in this store. Can be :private or :public.



28
29
30
31
32
33
34
# File 'lib/cocoapods/sandbox/headers_store.rb', line 28

def initialize(sandbox, relative_path, visibility_scope)
  @sandbox       = sandbox
  @relative_path = relative_path
  @search_paths  = []
  @search_paths_cache = {}
  @visibility_scope = visibility_scope
end