Method: Pod::Installer::InstallationOptions#incremental_installation
- Defined in:
- lib/cocoapods/installer/installation_options.rb
#incremental_installation ⇒ Boolean
Note:
this option defaults to false.
Whether to enable only regenerating targets and their associate projects that have changed since the previous installation.
188 |
# File 'lib/cocoapods/installer/installation_options.rb', line 188 option :incremental_installation, false |